@@ -1,7 +1,7 @@
 /* mpria.h -- C header file */
 /*
  * MPRIA - GNU Multi-Precision Rational Interval Arithmetic Library
- * Copyright (C) 2009-2014  Jerome Benoit <jgmbenoit@rezozer.net>
+ * Copyright (C) 2009-2016  Jerome Benoit <jgmbenoit@rezozer.net>
  *
  * This file is part of the GNU MPRIA Library.
  *
@@ -30,8 +30,8 @@
 /* MPRIA authoritative version macros */
 #define MPRIA_VERSION_MAJOR 0 /* major version number */
 #define MPRIA_VERSION_MINOR 7 /* minor version number or revision number */
-#define MPRIA_VERSION_MICRO 1 /* micro version number or major patch level*/
-/* #define MPRIA_VERSION_NANO 1 */ /* nano version number or minor patch level*/
+#define MPRIA_VERSION_MICRO 2 /* micro version number or major patch level*/
+/* #define MPRIA_VERSION_NANO 0 */ /* nano version number or minor patch level*/
 #define MPRIA_VERSION_EXTRA "" /* extra information as string */
 
 /* MPRIA version pack function-like macros */
@@ -49,10 +49,6 @@
 #include <gmp.h>
 #endif /* __GMP_H__ */
 
-#ifndef ULONG_MAX
-#define ULONG_MAX __GMP_ULONG_MAX
-#endif
-
 #define MPRI_PREC_BITS_NIL ULONG_MAX
 #define MPRI_PREC_BITS_HALF       11
 #define MPRI_PREC_BITS_SINGLE     24
@@ -238,6 +234,8 @@ void mpri_mid(mpq_ptr, mpri_srcptr);
 void mpri_get_q(mpq_ptr, mpri_srcptr);
 #endif
 
+void mpri_urandomm(mpq_ptr, mpri_srcptr, gmp_randstate_t);
+
 double mpri_get_d(mpri_srcptr);
 
 #if __GMP_INLINE_PROTOTYPES || defined (__GMP_FORCE_mpri_add)
